@@ -3,9 +3,9 @@ from enum import IntEnum
 
 from qtpy import QtWidgets, QtCore, QtGui
 
-from .menu import RibbonMenu
 from .category import (RibbonCategory, RibbonContextCategory, RibbonNormalCategory,
                        RibbonCategoryStyle, contextColors, RibbonContextCategories)
+from .menu import RibbonMenu
 from .tabbar import RibbonTabBar
 from .titlewidget import RibbonTitleWidget, RibbonApplicationButton
 from .utils import data_file_path
@@ -53,7 +53,7 @@ class RibbonBar(QtWidgets.QMenuBar):
     _ribbonVisible = True
 
     #: heights of the ribbon elements
-    _ribbonHeight = 240
+    _ribbonHeight = 200
 
     #: current tab index
     _currentTabIndex = 0
@@ -92,7 +92,7 @@ class RibbonBar(QtWidgets.QMenuBar):
         # Main layout
         self._mainLayout = QtWidgets.QVBoxLayout(self)
         self._mainLayout.setContentsMargins(5, 5, 5, 5)
-        self._mainLayout.setSpacing(5)
+        self._mainLayout.setSpacing(0)
         self._mainLayout.addWidget(self._titleWidget, 0)
         self._mainLayout.addWidget(self._stackedWidget, 1)
         self._mainLayout.setSizeConstraint(QtWidgets.QLayout.SetMinAndMaxSize)
@@ -218,20 +218,6 @@ class RibbonBar(QtWidgets.QMenuBar):
         """
         return self._titleWidget.tabBar()
 
-    def tabBarHeight(self) -> int:
-        """Get the height of the tab bar.
-
-        :return: The height of the tab bar.
-        """
-        return self._titleWidget.tabBarHeight()
-
-    def setTabBarHeight(self, height: int = 70):
-        """Set the height of the tab bar.
-
-        :param height: The height to set.
-        """
-        self._titleWidget.setTabBarHeight(height)
-
     def quickAccessToolBar(self) -> QtWidgets.QToolBar:
         """Return the quick access toolbar of the ribbon.
 
@@ -352,26 +338,28 @@ class RibbonBar(QtWidgets.QMenuBar):
 
         :param data: The dict of categories. The dict is of the form:
 
-                     {
-                         "category-title": {
-                             "style": RibbonCategoryStyle.Normal,
-                             "color": QtCore.Qt.red,
-                             "panels":
-                                 "panel-title": {
-                                     "showPanelOptionButton": True,
-                                     "widgets": {
-                                         "widget-name": {
-                                             "type": "Button",
-                                             "arguments": {
-                                                 "key1": "value1",
-                                                 "key2": "value2"
-                                             }
-                                         },
-                                     }
-                                 },
-                             },
-                         }
-                     }
+            .. code-block:: python
+            
+                {
+                    "category-title": {
+                        "style": RibbonCategoryStyle.Normal,
+                        "color": QtCore.Qt.red,
+                        "panels": {
+                            "panel-title": {
+                                "showPanelOptionButton": True,
+                                "widgets": {
+                                    "widget-name": {
+                                        "type": "Button",
+                                        "arguments": {
+                                            "key1": "value1",
+                                            "key2": "value2"
+                                        }
+                                    },
+                                }
+                            },
+                        },
+                    }
+                }
         :return: A dict of categories of the ribbon.
         """
         categories = {}
@@ -386,7 +374,7 @@ class RibbonBar(QtWidgets.QMenuBar):
         self,
         title: str,
         style=RibbonCategoryStyle.Normal,
-        color: QtGui.QColor = QtCore.Qt.blue,
+        color: QtGui.QColor = None,
     ) -> typing.Union[RibbonNormalCategory, RibbonContextCategory]:
         """Add a new category to the ribbon.
 
@@ -580,7 +568,7 @@ class RibbonBar(QtWidgets.QMenuBar):
             self.collapseRibbonButton().setToolTip("Expand Ribbon")
             self.collapseRibbonButton().setIcon(QtGui.QIcon(data_file_path('icons/down.png')))
             self._stackedWidget.setVisible(False)
-            self.setFixedSize(self.sizeHint().width(), self._titleWidget.tabBarHeight() + 5)
+            self.setFixedSize(self.sizeHint().width(), self._titleWidget.size().height() + 5)
 
     def ribbonVisible(self) -> bool:
         """Get the visibility of the ribbon.
